@@ -35,7 +35,10 @@ class GlobalSettings(ValueBag):
             if mod:
                 for key in dir(mod):
                     if key == key.upper():
-                        setattr(self, key, expand_path(getattr(mod, key)))
+                        v = getattr(mod, key)
+                        if isinstance(v, (str, unicode)):
+                            v = expand_path(v)
+                        setattr(self, key, v)
                 
 
 settings = GlobalSettings({
